ewa.rules.FileTimeMatch

Package ewa :: Module rules :: Class FileTimeMatch |
[hide private]
[frames] | no frames]

# Class FileTimeMatch

source code

    object --+
             |
     _jsonable --+
                 |
                FileTimeMatch

returns true if a date encoded in a string falls within a date range

Instance Methods | [hide private]
__init__(self, start=datetime.datetime(1, 1, 1, 0, 0), end=datetime.datetime(9999, 12, 31, 23, 59, 59, 999999), dateregex=`'``\\d{6}``'`, dateformat=`'``%m%d%y``'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
match(self, target) | source code
Inherited from `_jsonable`: `to_jsondata` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, start=datetime.datetime(1, 1, 1, 0, 0), end=datetime.datetime(9999, 12, 31, 23, 59, 59, 999999), dateregex=`'``\\d{6}``'`, dateformat=`'``%m%d%y``'`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)